Description Usage Arguments Details Value
View source: R/class-date_tbl.R
date_to_dt_dttm() will coerce the input to a scalar Date or datetime
object if possible; if not, it will throw an error.
1 |
date |
An object to be coerced to |
date_to_dttm() returns a Date when:
a string coercable to Date does not contain time information
a numeric coerced to Date is closer to the current datetime than
the same numeric coerced to datetime
date_to_dt_dttm() returns a datetime when:
a string coercable to datetime contains time information
a numeric coerced to datetime is closer to the current datetime
than the same numeric coerced to Date
A Date or datetime object, depending on the input
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.