R/load_redcap_records.R
load-case-projects.Rdload_nit() and load_nca() load the latest data downloaded from the
respective REDcap project. To find the file paths to these data, use
path_nit() or
path_nca(). To download the data, use
download_nit() or
download_nca().
load_nit(date = NULL, path = path_nit(date), clean_names = TRUE, ...) load_nca(date = NULL, path = path_nca(date), clean_names = TRUE, ...)
| date | The download date of the file to read; the default ( |
|---|---|
| path | The path to the file to read; if supplied, the function will read this file instead |
| clean_names | Should column names be cleaned by
|
| ... | Additional parameters to pass to
|
A tibble if reading one file; a list of tibbles if reading
multiple