Description Usage Arguments Details Value
View source: R/read_file_delim.R
read_file_delim() reads delimited files using
vroom(). This allows the use of ALTREP columns,
which don't load data into memory until they are needed.
1 2 3 4 5 6 7 8 9 |
file |
path to a local file. |
col_select |
One or more selection expressions, like in
|
col_types |
One of If If a column specification created by Alternatively, you can use a compact string representation where each
character represents one column:
c = character, i = integer, n = number, d = double,
l = logical, f = factor, D = date, T = date time, t = time, ? = guess, or
|
na |
Character vector of strings to interpret as missing values. Set this
option to |
guess_max |
Maximum number of records to use for guessing column types. |
delim |
One or more characters used to delimit fields within a
file. If |
... |
Additional arguments to pass to |
By default, read_file_delim() does not attempt to guess column types and
reads all columns as character. This can be changed by setting
col_types = vroom::cols(.default = vroom::col_guess()). If columns are
guessed, the default is to use all rows; this can be changed by setting
guess_max to a different value.
This saves a significant amount of time and space when loading data with many rarely used columns.
A tibble if reading one file; a list of tibbles if reading
multiple
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.